@@ -5,7 +5,7 @@
 #   Kim-Anh Le Cao, The University of Queensland, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 #
 # created: 22-04-2015
-# last modified: 13-04-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2015
 #
@@ -36,20 +36,17 @@
 # indY: to supply if Y is missing, indicate the position of the outcome in the list X.
 # study: grouping factor indicating which samples are from the same study
 # ncomp: numeric vector of length the number of blocks in \code{X}. The number of components to include in the model for each block (does not necessarily need to take the same value for each block). By default set to 2 per block.
-# keepX.constraint: A list of same length as X. Each entry keepX.constraint[[i]] is a list containing which variables of X[[i]] are to be kept on each of the first PLS-components
-# keepY.constraint: Only used if Y is provided, otherwise extracted from keepX.constraint. A list containing which variables of Y are to be kept on each of the first PLS-components
 # keepX: A vector of same length as X.  Each entry keepX[i] is the number of X[[i]]-variables kept in the model on the last components (once all keepX.constraint[[i]] are used).
 # keepY: Only used if Y is provided. Each entry keepY[i] is the number of Y-variables kept in the model on the last components.
 # design: the input design.
 # scheme: the input scheme, one of "horst", "factorial" or ""centroid". Default to "centroid"
 # mode: input mode, one of "canonical", "classic", "invariant" or "regression". Default to "regression"
 # scale: boleean. If scale = TRUE, each block is standardized to zero means and unit variances (default: TRUE).
-# bias: boleean. A logical value for biaised or unbiaised estimator of the var/cov (defaults to FALSE).
 # init: intialisation of the algorithm, one of "svd" or "svd.single". Default to "svd"
 # tol: Convergence stopping value.
-# verbose: if set to \code{TRUE}, reports progress on computing.
 # max.iter: integer, the maximum number of iterations.
 # near.zero.var: boolean, see the internal \code{\link{nearZeroVar}} function (should be set to TRUE in particular for data with many zero values). Setting this argument to FALSE (when appropriate) will speed up the computations
+# all.outputs: calculation of non-essential outputs (e.g. explained variance, loadings.Astar, etc)
 
 
 
@@ -58,46 +55,40 @@ Y,
 indY,
 study,
 ncomp = 2,
-keepX.constraint,
-keepY.constraint,
 keepX,
 keepY,
 design,
 scheme,
 mode,
 scale = TRUE,
-bias,
 init ,
 tol = 1e-06,
-verbose,
 max.iter = 100,
-near.zero.var = FALSE)
+near.zero.var = FALSE,
+all.outputs = TRUE)
 {
     # call to 'internal_wrapper.mint.block'
     result = internal_wrapper.mint.block(X=X, Y=Y, indY=indY, study=study, ncomp=ncomp,
-    keepX.constraint=keepX.constraint, keepY.constraint=keepY.constraint, keepX=keepX, keepY=keepY,
-    design=design, scheme=scheme, mode=mode, scale=scale, bias=bias, init=init, tol=tol,
-    verbose=verbose, max.iter=max.iter, near.zero.var=near.zero.var)
+    keepX=keepX, keepY=keepY,
+    design=design, scheme=scheme, mode=mode, scale=scale, init=init, tol=tol,
+    max.iter=max.iter, near.zero.var=near.zero.var, all.outputs = all.outputs)
     
     # choose the desired output from 'result'
     out = list(
         call = match.call(),
-        X = result$X,
-        Y = result$Y[[1]],
+        X = result$A,
+        Y = result$A[[1]],
         ncomp = result$ncomp,
         mode = result$mode,
         study = result$study,
         keepX = result$keepA[-result$indY],
         keepY = result$keepA[result$indY][[1]],
-        keepX.constraint = result$keepA.constraint[-result$indY],
-        keepY.constraint = result$keepA.constraint[result$indY][[1]],
         variates = result$variates,
         loadings = result$loadings,
         variates.partial = result$variates.partial,
         loadings.partial = result$loadings.partial,
         names = result$names,
         init = result$init,
-        bias = result$bias,
         tol = result$tol,
         iter = result$iter,
         max.iter = result$max.iter,
