@@ -4,7 +4,7 @@
 #   Kim-Anh Le Cao, The University of Queensland, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 #
 # created: 22-04-2015
-# last modified: 01-03-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2015
 #
@@ -33,11 +33,13 @@
 # X: numeric matrix of predictors
 # Y: a factor or a class vector for the discrete outcome
 # ncomp: the number of components to include in the model. Default to 2.
+# mode: input mode, one of "canonical", "classic", "invariant" or "regression". Default to "regression"
 # study: grouping factor indicating which samples are from the same study
 # scale: boleean. If scale = TRUE, each block is standardized to zero means and unit variances (default: TRUE).
 # tol: Convergence stopping value.
 # max.iter: integer, the maximum number of iterations.
 # near.zero.var: boolean, see the internal \code{\link{nearZeroVar}} function (should be set to TRUE in particular for data with many zero values). Setting this argument to FALSE (when appropriate) will speed up the computations
+# all.outputs: calculation of non-essential outputs (e.g. explained variance, loadings.Astar, etc)
 
 
 mint.plsda = function(X,
@@ -48,7 +50,8 @@ study,
 scale = TRUE,
 tol = 1e-06,
 max.iter = 100,
-near.zero.var = FALSE)
+near.zero.var = FALSE,
+all.outputs = TRUE)
 {
     
     
@@ -70,15 +73,15 @@ near.zero.var = FALSE)
 
     # call to 'internal_wrapper.mint'
     result = internal_wrapper.mint(X = X, Y = Y.mat, study = study, ncomp = ncomp, scale = scale, near.zero.var = near.zero.var, mode = mode,
-    max.iter = max.iter, tol = tol)
+    max.iter = max.iter, tol = tol, all.outputs = all.outputs)
 
 
     # choose the desired output from 'result'
     out = list(
         call = match.call(),
-        X = result$X[-result$indY][[1]],
+        X = result$A[-result$indY][[1]],
         Y = Y,
-        ind.mat = result$X[result$indY][[1]],
+        ind.mat = result$A[result$indY][[1]],
         ncomp = result$ncomp,
         study = result$study,
         mode = result$mode,
