@@ -4,7 +4,7 @@
 #   Kim-Anh Le Cao, The University of Queensland, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 #
 # created: 22-04-2015
-# last modified: 24-02-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2015
 #
@@ -33,15 +33,15 @@
 # X: numeric matrix of predictors
 # Y: numeric vector or matrix of responses
 # ncomp: the number of components to include in the model. Default to 2.
+# mode: input mode, one of "canonical", "classic", "invariant" or "regression". Default to "regression"
 # study: grouping factor indicating which samples are from the same study
-# keepX.constraint: A list containing which variables of X are to be kept on each of the first PLS-components.
-# keepY.constraint: A list containing which variables of Y are to be kept on each of the first PLS-components
 # keepX: number of \eqn{X} variables kept in the model on the last components (once all keepX.constraint[[i]] are used).
 # keepY: number of \eqn{Y} variables kept in the model on the last components.
 # scale: boleean. If scale = TRUE, each block is standardized to zero means and unit variances (default: TRUE).
 # tol: Convergence stopping value.
 # max.iter: integer, the maximum number of iterations.
 # near.zero.var: boolean, see the internal \code{\link{nearZeroVar}} function (should be set to TRUE in particular for data with many zero values). Setting this argument to FALSE (when appropriate) will speed up the computations
+# all.outputs: calculation of non-essential outputs (e.g. explained variance, loadings.Astar, etc)
 
 
 mint.spls = function(X,
@@ -49,33 +49,30 @@ Y,
 ncomp = 2,
 mode = c("regression", "canonical", "invariant", "classic"),
 study,
-keepX.constraint=NULL,
-keepY.constraint=NULL,
 keepX=rep(ncol(X), ncomp),
 keepY=rep(ncol(Y), ncomp),
 scale = TRUE,
 tol = 1e-06,
 max.iter = 100,
-near.zero.var = FALSE)
+near.zero.var = FALSE,
+all.outputs = TRUE)
 {
 
     # call to 'internal_wrapper.mint'
     result = internal_wrapper.mint(X = X, Y = Y, ncomp = ncomp, scale = scale, near.zero.var = near.zero.var, study = study, mode = mode,
-    keepX = keepX, keepY = keepY, keepX.constraint = keepX.constraint, keepY.constraint = keepY.constraint,
-    max.iter = max.iter, tol = tol)
+    keepX = keepX, keepY = keepY,
+    max.iter = max.iter, tol = tol, all.outputs = all.outputs)
     
     # choose the desired output from 'result'
     out = list(
         call = match.call(),
-        X = result$X[-result$indY][[1]],
-        Y = result$X[result$indY][[1]],
+        X = result$A[-result$indY][[1]],
+        Y = result$A[result$indY][[1]],
         ncomp = result$ncomp,
         study = result$study,
         mode = result$mode,
-        keepX = result$keepA[[1]],
-        keepY = result$keepA[[2]],
-        keepX.constraint = result$keepA.constraint[[1]],
-        keepY.constraint = result$keepA.constraint[[2]],
+        keepX = result$keepX,
+        keepY = result$keepY,
         variates = result$variates,
         loadings = result$loadings,
         variates.partial = result$variates.partial,
