@@ -4,7 +4,7 @@
 #   Kim-Anh Le Cao, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 
 # created: 2011
-# last modified: 24-05-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2011
 #
@@ -32,12 +32,14 @@
 # X: numeric matrix of predictors
 # Y: a factor or a class vector for the discrete outcome
 # ncomp: the number of components to include in the model. Default to 2.
-# keepX.constraint: A list containing which variables of X are to be kept on each of the first PLS-components.
 # keepX: number of \eqn{X} variables kept in the model on the last components (once all keepX.constraint[[i]] are used).
 # scale: boleean. If scale = TRUE, each block is standardized to zero means and unit variances (default: TRUE).
 # tol: Convergence stopping value.
 # max.iter: integer, the maximum number of iterations.
 # near.zero.var: boolean, see the internal \code{\link{nearZeroVar}} function (should be set to TRUE in particular for data with many zero values). Setting this argument to FALSE (when appropriate) will speed up the computations
+# logratio: one of "none", "CLR"
+# multilevel: repeated measurement. `multilevel' is passed to multilevel(design = ) in withinVariation. Y is ommited and shouldbe included in `multilevel'
+# all.outputs: calculation of non-essential outputs (e.g. explained variance, loadings.Astar, etc)
 
 
 
@@ -46,13 +48,13 @@ Y,
 ncomp = 2,
 mode = c("regression", "canonical", "invariant", "classic"),
 keepX,
-keepX.constraint=NULL,
 scale = TRUE,
 tol = 1e-06,
 max.iter = 100,
 near.zero.var = FALSE,
 logratio = "none",   # one of "none", "CLR"
-multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinVariation. Y is ommited and shouldbe included in multilevel design
+multilevel = NULL,
+all.outputs = TRUE)    
 {
     
     
@@ -96,29 +98,29 @@ multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinV
     
     # call to 'internal_wrapper.mint'
     result = internal_wrapper.mint(X = X, Y = Y.mat, ncomp = ncomp, scale = scale, near.zero.var = near.zero.var, mode = mode,
-    keepX = keepX, keepX.constraint = keepX.constraint, max.iter = max.iter, tol = tol, logratio = logratio,
-    multilevel = multilevel, DA = TRUE)
+    keepX = keepX, max.iter = max.iter, tol = tol, logratio = logratio,
+    multilevel = multilevel, DA = TRUE, all.outputs = all.outputs)
     
 
     # choose the desired output from 'result'
     out = list(
         call = match.call(),
-        X = result$X[-result$indY][[1]],
+        X = result$A[-result$indY][[1]],
         Y = if (is.null(multilevel))
             {
                 Y
             } else {
                 result$Y.factor
             },
-        ind.mat = result$X[result$indY][[1]],
+        ind.mat = result$A[result$indY][[1]],
         ncomp = result$ncomp,
         mode = result$mode,
-        keepX = result$keepA[[1]],
-        keepY = result$keepA[[2]],
-        keepX.constraint = result$keepA.constraint[[1]],
-        keepY.constraint = result$keepA.constraint[[2]],
+        keepA=result$keepA,
+        keepX = result$keepX,
+        keepY = result$keepY,
         variates = result$variates,
         loadings = result$loadings,
+        loadings.star = result$loadings.star,
         names = result$names,
         tol = result$tol,
         iter = result$iter,
@@ -128,8 +130,7 @@ multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinV
         logratio = logratio,
         explained_variance = result$explained_variance,#[-result$indY],
         input.X = result$input.X,
-        mat.c = result$mat.c,
-        defl.matrix = result$defl.matrix
+        mat.c = result$mat.c#,
         )
     
     class(out) = c("splsda","spls","DA")
